# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.workflowexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


class WorkflowExecutionCommandControllerStub(object):
    """WorkflowExecutionCommandController handles write operations (Create, Update, Delete) for WorkflowExecution resources.

    This service follows the Command-Query Separation (CQS) pattern:
    - CommandController: Write operations (create, update, delete)
    - QueryController: Read operations (get, list, search)

    Authorization:
    All RPCs use custom authorization logic implemented in middleware.
    Custom authorization is needed because:
    - create: Must verify user has "execute" permission on the referenced WorkflowInstance
    - update: Only the workflow runner (system) can update execution status, not users

    Service Options:
    - api_resource_kind: workflow_execution - Links this service to the WorkflowExecution resource
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/create',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/update',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.updateStatus = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/updateStatus',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.WorkflowExecutionUpdateStatusInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.submitApproval = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/submitApproval',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.SubmitWorkflowApprovalInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.sendSignal = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/sendSignal',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.SendSignalInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.cancel = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/cancel',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.CancelWorkflowExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.terminate = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/terminate',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.TerminateWorkflowExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.recover = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/recover',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.RecoverWorkflowExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.pause = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/pause',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.PauseWorkflowExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)
        self.resume = channel.unary_unary(
                '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/resume',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.ResumeWorkflowExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                _registered_method=True)


class WorkflowExecutionCommandControllerServicer(object):
    """WorkflowExecutionCommandController handles write operations (Create, Update, Delete) for WorkflowExecution resources.

    This service follows the Command-Query Separation (CQS) pattern:
    - CommandController: Write operations (create, update, delete)
    - QueryController: Read operations (get, list, search)

    Authorization:
    All RPCs use custom authorization logic implemented in middleware.
    Custom authorization is needed because:
    - create: Must verify user has "execute" permission on the referenced WorkflowInstance
    - update: Only the workflow runner (system) can update execution status, not users

    Service Options:
    - api_resource_kind: workflow_execution - Links this service to the WorkflowExecution resource
    """

    def create(self, request, context):
        """Create and trigger a new workflow execution.

        This RPC creates a WorkflowExecution resource and immediately triggers it for execution.
        The workflow execution engine (Temporal) picks up the execution and begins processing tasks.

        Input Validation:
        - metadata.org must be specified
        - spec.workflow_instance_id is required and must reference an existing WorkflowInstance
        - api_version must be exactly "agentic.stigmer.ai/v1"
        - kind must be exactly "WorkflowExecution"

        Authorization:
        Custom authorization verifies:
        1. User has "execute" permission on the referenced WorkflowInstance
        2. User has access to all referenced Environments (from WorkflowInstance)
        3. User has access to all referenced Secrets (from runtime_env secret_refs)

        Execution Flow:
        1. Validate input (proto validation + business rules)
        2. Check authorization (user can execute WorkflowInstance)
        3. Create WorkflowExecution resource in database
        4. Set initial status.phase = EXECUTION_PENDING
        5. Trigger workflow in execution engine (Temporal)
        6. Return WorkflowExecution with status.phase = EXECUTION_PENDING or EXECUTION_IN_PROGRESS

        Status After Create:
        - status.phase: EXECUTION_PENDING (or EXECUTION_IN_PROGRESS if already picked up)
        - status.audit.created_at: Current timestamp
        - status.audit.created_by: Authenticated user ID
        - status.started_at: Not set yet (set when phase transitions to IN_PROGRESS)

        Use Cases:

        1. API-Triggered Execution:
        - User calls API to execute a workflow
        - Input: WorkflowExecution with spec.workflow_instance_id and spec.trigger_message
        - Output: WorkflowExecution with generated ID and PENDING status

        2. Webhook-Triggered Execution:
        - External system (Stripe, GitHub, etc.) sends webhook
        - Webhook handler creates WorkflowExecution with webhook payload in spec.trigger_message
        - spec.trigger_metadata captures webhook source, event type, timestamp

        3. Scheduled Execution:
        - Scheduler service creates WorkflowExecution at scheduled time
        - spec.trigger_metadata includes schedule ID and cron expression

        4. UI-Triggered Execution:
        - User clicks "Execute" button in web console
        - UI creates WorkflowExecution with user-provided inputs

        5. Workflow Chaining (Workflow A triggers Workflow B):
        - Workflow A completes, creates WorkflowExecution for Workflow B
        - spec.trigger_message contains output from Workflow A
        - spec.trigger_metadata includes parent workflow execution ID

        Error Cases:

        - INVALID_ARGUMENT:
        - workflow_instance_id is missing or invalid
        - org is missing
        - api_version or kind is incorrect

        - PERMISSION_DENIED:
        - User doesn't have "execute" permission on WorkflowInstance
        - User doesn't have access to referenced Environments
        - User doesn't have access to referenced Secrets

        - NOT_FOUND:
        - Referenced WorkflowInstance doesn't exist
        - Referenced Environment doesn't exist
        - Referenced Secret doesn't exist

        - FAILED_PRECONDITION:
        - WorkflowInstance is in invalid state (e.g., archived, disabled)
        - Too many concurrent executions (quota exceeded)

        Example Request:
        {
        "api_version": "agentic.stigmer.ai/v1",
        "kind": "WorkflowExecution",
        "metadata": {
        "name": "customer-onboarding-20250111-143022",
        "org": "acme"
        },
        "spec": {
        "workflow_instance_id": "wfi-customer-onboarding-prod",
        "trigger_message": "New signup: john.doe@example.com",
        "trigger_metadata": {
        "source": "api",
        "caller_id": "usr-jane-admin",
        "timestamp": "2025-01-11T14:30:22Z"
        },
        "runtime_env": {
        "CUSTOMER_EMAIL": { "value": "john.doe@example.com" }
        }
        }
        }

        Example Response:
        {
        "api_version": "agentic.stigmer.ai/v1",
        "kind": "WorkflowExecution",
        "metadata": {
        "id": "wfx-abc123xyz456",  // Auto-generated
        "name": "customer-onboarding-20250111-143022",
        "org": "acme"
        },
        "spec": { ... },  // Same as request
        "status": {
        "phase": 1,  // EXECUTION_PENDING
        "audit": {
        "created_at": "2025-01-11T14:30:22Z",
        "created_by": "usr-jane-admin"
        }
        }
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Update execution with full state.
        Used by users to update execution configuration (spec fields).
        No individual field updates - always provide complete state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateStatus(self, request, context):
        """Update execution status during workflow execution.
        Used by workflow-runner to send progressive status updates (messages, task states, phase, etc.)
        This RPC is optimized for frequent status updates and merges status fields with existing state.

        This RPC is used by the workflow execution engine (Temporal) to update the status
        of a running workflow execution. Users cannot call this RPC directly.

        What Can Be Updated:
        - status.phase (PENDING → IN_PROGRESS → COMPLETED/FAILED/CANCELLED)
        - status.tasks (update task statuses, outputs, errors)
        - status.output (set final workflow output when COMPLETED)
        - status.error (set error message when FAILED)
        - status.started_at (set when execution starts)
        - status.completed_at (set when execution finishes)

        What Cannot Be Updated:
        - spec.* (user inputs are immutable after creation)
        - metadata.id (resource ID is immutable)
        - status.audit.created_at (creation timestamp is immutable)

        Authorization:
        Custom authorization verifies:
        1. Caller is the workflow runner service (system identity, not a user)
        2. Only status fields are being modified (spec and metadata unchanged)

        Update Flow:
        1. Workflow runner executes a task
        2. Task completes/fails
        3. Workflow runner calls updateStatus() with:
        - Updated status.tasks (new task status, output/error)
        - Updated status.phase (if all tasks done)
        4. Backend validates and persists update
        5. Backend broadcasts update via WebSocket (for real-time UI updates)

        Use Cases:

        1. Task Started:
        - Workflow runner updates status.tasks[i].status = IN_PROGRESS

        2. Task Completed:
        - Workflow runner updates status.tasks[i].status = COMPLETED
        - Workflow runner sets status.tasks[i].output

        3. Task Failed:
        - Workflow runner updates status.tasks[i].status = FAILED
        - Workflow runner sets status.tasks[i].error
        - Workflow runner updates status.phase = EXECUTION_FAILED
        - Workflow runner sets status.error
        - Workflow runner sets status.completed_at

        4. Workflow Completed:
        - Workflow runner updates status.phase = EXECUTION_COMPLETED
        - Workflow runner sets status.output
        - Workflow runner sets status.completed_at

        5. Workflow Cancelled:
        - Workflow runner receives cancellation signal
        - Workflow runner updates status.phase = EXECUTION_CANCELLED
        - Workflow runner sets status.completed_at

        Error Cases:

        - PERMISSION_DENIED:
        - Caller is not the workflow runner service (users cannot update status)

        - INVALID_ARGUMENT:
        - Trying to modify spec or metadata (only status can be updated)
        - Invalid phase transition (e.g., COMPLETED → IN_PROGRESS)

        - NOT_FOUND:
        - WorkflowExecution with given ID doesn't exist

        Example Request (Task Completed):
        {
        "metadata": {
        "id": "wfx-abc123xyz456"
        },
        "status": {
        "phase": 2,  // EXECUTION_IN_PROGRESS
        "completed_tasks": 1,
        "tasks": [
        {
        "task_id": "task-1",
        "task_name": "validate_email",
        "status": 3,  // WORKFLOW_TASK_COMPLETED
        "output": { "valid": true },
        "completed_at": "2025-01-11T14:30:27Z"
        },
        {
        "task_id": "task-2",
        "task_name": "create_account",
        "status": 2,  // WORKFLOW_TASK_IN_PROGRESS
        "timestamp": "2025-01-11T14:30:27Z"
        }
        ]
        }
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def submitApproval(self, request, context):
        """Submit approval for a child agent's tool execution (HITL Phase 5.3).

        This RPC forwards the approval decision to the child AgentExecution that
        is waiting for approval. The child is identified by the child_agent_execution_id
        in status.pending_approval.

        ## Behavior

        When a workflow invokes an agent that requires tool approval, the approval
        request surfaces at the workflow level via status.pending_approval. Users can
        submit their decision through this RPC, which forwards it to the child agent.

        The approval is forwarded to the child via AgentExecution.submitApproval RPC,
        ensuring consistent validation and Temporal workflow signaling.

        ## Preconditions

        - status.pending_approval must be populated
        - tool_call_id must match status.pending_approval.tool_call_id
        - status.pending_approval.child_agent_execution_id must not be empty
        - User must have can_edit permission on the workflow execution

        ## State Transitions

        After successful approval:
        - Approval is forwarded to child AgentExecution
        - Child agent resumes execution based on action (APPROVE/SKIP/REJECT)
        - Child agent clears its pending_approval, which triggers signal to parent
        - WorkflowExecution.status.pending_approval is eventually cleared
        - Workflow task status returns from WAITING_APPROVAL to IN_PROGRESS

        ## Approval Actions

        - APPROVE: Tool executes with the provided arguments
        - SKIP: Tool execution is skipped, agent continues with skip message
        - REJECT: Agent execution fails with rejection error

        ## Error Cases

        - NOT_FOUND: Workflow execution doesn't exist
        - PERMISSION_DENIED: User doesn't have can_edit permission
        - FAILED_PRECONDITION: No pending approval, or child agent not waiting
        - INVALID_ARGUMENT: Tool call ID mismatch, or action is UNSPECIFIED
        - UNAVAILABLE: Failed to forward to child agent (transient error)

        ## Idempotency

        If the same approval is submitted twice (same workflow execution, tool_call_id,
        and action), the second call is a no-op if the approval was already processed.

        ## Alternative: Direct Agent Approval

        Users can also submit approvals directly via AgentExecution.submitApproval
        using the child_agent_execution_id. Both paths are equivalent and result
        in the same state transitions.

        @since Phase 5.3 (Approval Forwarding)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Delete an execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def sendSignal(self, request, context):
        """─────────────────────────────────────────────────────────────────────────────
        Signal Operations

        These RPCs enable communication with running workflow executions via
        Temporal signals. Signals are used to deliver external events to workflows
        waiting at LISTEN tasks.
        ─────────────────────────────────────────────────────────────────────────────

        Send a signal to a running workflow execution.

        Delivers a signal to a workflow execution, typically to unblock a LISTEN task.
        Uses Temporal's SignalWithStart API internally for race-proof delivery.

        ## Behavior

        1. Validates execution exists and is in a signalable phase
        2. Uses Temporal SignalWithStart for atomic delivery:
        - If workflow exists → sends signal immediately
        - If workflow not started yet → starts workflow, then sends signal
        3. Signal is delivered to workflow's signal channel
        4. LISTEN task waiting for this signal will unblock and continue
        5. Returns the current WorkflowExecution state

        ## Preconditions

        - Execution must be in EXECUTION_PENDING or EXECUTION_IN_PROGRESS phase
        - Cannot signal terminal executions (COMPLETED, FAILED, CANCELLED, TERMINATED)
        - User must have can_edit permission on the workflow execution

        ## Race-Proof Delivery (SignalWithStart)

        This RPC uses Temporal's SignalWithStart API to handle the race condition
        where a signal might arrive before the workflow is fully started:
        - Traditional SignalWorkflow fails with "WorkflowNotFound" if called too early
        - SignalWithStart atomically: starts workflow if needed, then sends signal
        - Guarantees signal delivery even in race conditions

        ## Signal Matching

        The signal_name must match the signal ID defined in the workflow's LISTEN task:

        Workflow YAML:
        - waitForPayment:
        listen:
        to:
        one:
        with:
        id: payment_confirmed  # <-- signal_name must match this
        type: signal

        API Call:
        { "signal_name": "payment_confirmed", "payload": {...} }

        ## Error Cases

        - NOT_FOUND: Workflow execution doesn't exist
        - PERMISSION_DENIED: User doesn't have can_edit permission
        - FAILED_PRECONDITION: Execution is in a terminal phase
        - INVALID_ARGUMENT: execution_id or signal_name is empty

        ## Example Request

        {
        "execution_id": "wfx-abc123xyz456",
        "signal_name": "payment_confirmed",
        "payload": {
        "transaction_id": "txn_123",
        "amount": 99.99,
        "currency": "USD"
        }
        }

        ## Example Response

        Returns the current WorkflowExecution state (phase may still be IN_PROGRESS
        as the workflow continues after receiving the signal).

        @since Gap B1 (Signal-With-Start for race-proof event delivery)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cancel(self, request, context):
        """─────────────────────────────────────────────────────────────────────────────
        Lifecycle Control Operations

        These RPCs control the workflow execution lifecycle, mapping to Temporal
        workflow operations. They enable users to gracefully stop, force-stop,
        or recover workflow executions.
        ─────────────────────────────────────────────────────────────────────────────

        Cancel a running workflow execution gracefully.

        Sends a cancellation signal to the workflow via Temporal's CancelWorkflow API.
        The workflow code can handle the cancellation signal to perform cleanup
        (e.g., compensation logic, resource cleanup, notifications) before
        transitioning to the CANCELLED phase.

        Temporal Equivalent: `temporal workflow cancel --workflow-id <id>`

        ## Behavior

        1. Validates execution exists and is in a cancellable phase
        2. Sends cancellation signal to Temporal workflow
        3. Workflow code receives the signal and can perform cleanup
        4. Execution transitions to EXECUTION_CANCELLED phase
        5. Returns updated WorkflowExecution with new phase

        ## Preconditions

        - Execution must be in EXECUTION_PENDING or EXECUTION_IN_PROGRESS phase
        - Cannot cancel already-terminal executions (COMPLETED, FAILED, CANCELLED, TERMINATED)

        ## State Transitions

        - status.phase: PENDING/IN_PROGRESS → CANCELLED
        - status.completed_at: Set to current timestamp
        - In-progress tasks: May complete cleanup or be interrupted

        ## Idempotency

        Cancelling an already-cancelled execution succeeds as a no-op.
        The call returns the current execution state without side effects.
        This ensures safe retry of cancel requests.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission on the execution
        - FAILED_PRECONDITION: Execution is in a terminal phase (COMPLETED, FAILED, TERMINATED)
        - INVALID_ARGUMENT: ID is empty or malformed

        ## Example Request

        {
        "id": "wfx-abc123xyz456",
        "reason": "Customer requested cancellation - order no longer needed"
        }

        ## Example Response

        {
        "api_version": "agentic.stigmer.ai/v1",
        "kind": "WorkflowExecution",
        "metadata": { "id": "wfx-abc123xyz456" },
        "status": {
        "phase": 5,  // EXECUTION_CANCELLED
        "completed_at": "2026-02-07T18:30:00Z"
        }
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def terminate(self, request, context):
        """Terminate a workflow execution immediately.

        Force-stops the workflow via Temporal's TerminateWorkflow API without
        allowing cleanup. Unlike cancel, the workflow code cannot respond to
        termination - it is stopped immediately. Use this for stuck or
        unresponsive workflows that don't respond to cancellation.

        Temporal Equivalent: `temporal workflow terminate --workflow-id <id>`

        ## Behavior

        1. Validates execution exists and is in a terminable phase
        2. Force-kills workflow via Temporal (no signal sent to workflow)
        3. Execution transitions to EXECUTION_TERMINATED phase immediately
        4. No cleanup callbacks or defer blocks are executed
        5. Returns updated WorkflowExecution with TERMINATED phase

        ## Preconditions

        - Execution must be in EXECUTION_PENDING or EXECUTION_IN_PROGRESS phase
        - Cannot terminate already-terminal executions

        ## State Transitions

        - status.phase: PENDING/IN_PROGRESS → TERMINATED
        - status.completed_at: Set to current timestamp
        - status.error: May contain termination reason
        - In-progress tasks: Stopped abruptly (no cleanup)

        ## Terminated vs Cancelled

        | Aspect | cancel | terminate |
        |--------|--------|-----------|
        | Signal to workflow | Yes (can handle) | No |
        | Cleanup opportunity | Yes | No |
        | Use case | Normal stop | Stuck workflows |
        | Can recover? | No | No |

        ## Idempotency

        Terminating an already-terminated execution succeeds as a no-op.
        The call returns the current execution state without side effects.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission on the execution
        - FAILED_PRECONDITION: Execution is in a terminal phase
        - INVALID_ARGUMENT: ID is empty or malformed

        ## Example Request

        {
        "id": "wfx-abc123xyz456",
        "reason": "Workflow stuck for 2 hours, not responding to cancel"
        }

        ## Example Response

        {
        "api_version": "agentic.stigmer.ai/v1",
        "kind": "WorkflowExecution",
        "metadata": { "id": "wfx-abc123xyz456" },
        "status": {
        "phase": 6,  // EXECUTION_TERMINATED
        "completed_at": "2026-02-07T18:35:00Z",
        "error": "Terminated by operator: Workflow stuck for 2 hours"
        }
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def recover(self, request, context):
        """Recover a failed workflow execution from the last checkpoint.

        Resumes execution from the last successful point using Temporal's
        ResetWorkflow API. Completed work is preserved - successful tasks
        are NOT re-executed. This enables "retry and resume" semantics
        without duplicating side effects.

        Temporal Equivalent: `temporal workflow reset --workflow-id <id> --type LastWorkflowTask`

        ## Behavior

        1. Validates execution is in FAILED phase (recoverable)
        2. Identifies the last successful checkpoint in workflow history
        3. Creates new Temporal run from that checkpoint via ResetWorkflow
        4. Execution transitions from FAILED to IN_PROGRESS phase
        5. Workflow continues from where it failed
        6. Returns updated WorkflowExecution with IN_PROGRESS phase

        ## Preconditions

        - Execution must be in EXECUTION_FAILED phase
        - TERMINATED executions cannot be recovered (intentional hard stop)
        - CANCELLED executions cannot be recovered (intentional user action)
        - COMPLETED executions don't need recovery

        ## State Transitions

        - status.phase: FAILED → IN_PROGRESS
        - status.completed_at: Cleared (execution is running again)
        - status.error: Cleared (no longer failed)
        - Completed tasks: Preserved (not re-executed)
        - Failed tasks: Reset to pending, will be retried

        ## Recovery vs Restart

        | Aspect | recover | Create new execution |
        |--------|---------|----------------------|
        | Completed work | Preserved | Lost (re-executed) |
        | Side effects | Not duplicated | May duplicate |
        | Execution ID | Same | New ID |
        | Use case | Resume after fix | Start fresh |

        ## Idempotency

        If recovery already succeeded (execution is now IN_PROGRESS from a
        previous recover call), the call succeeds as a no-op and returns
        the current execution state.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission on the execution
        - FAILED_PRECONDITION:
        - Execution is not in FAILED phase
        - Execution is TERMINATED (cannot recover)
        - Execution is CANCELLED (cannot recover)
        - INVALID_ARGUMENT: ID is empty or malformed

        ## Example Request

        {
        "id": "wfx-abc123xyz456",
        "reason": "Stripe API recovered, resuming payment processing"
        }

        ## Example Response

        {
        "api_version": "agentic.stigmer.ai/v1",
        "kind": "WorkflowExecution",
        "metadata": { "id": "wfx-abc123xyz456" },
        "status": {
        "phase": 2,  // EXECUTION_IN_PROGRESS
        "started_at": "2026-02-07T10:00:00Z",
        "tasks": [
        { "task_id": "task-1", "status": 3 },  // COMPLETED (preserved)
        { "task_id": "task-2", "status": 2 }   // IN_PROGRESS (resumed)
        ]
        }
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def pause(self, request, context):
        """Pause a running workflow execution.

        Temporarily stops the workflow at its current checkpoint. Unlike cancel,
        the execution is NOT terminal and can be resumed later from where it left off.
        The workflow gracefully checkpoints and exits, preserving all progress.

        ## Behavior

        1. Validates execution exists and is in a pausable phase
        2. Sends "pause" signal to Temporal workflow
        3. Workflow receives signal and sets pauseRequested flag
        4. Running activities are gracefully cancelled (checkpoints saved)
        5. Execution transitions to EXECUTION_PAUSED phase
        6. Workflow waits for resume signal (no resources consumed)
        7. Returns updated WorkflowExecution with PAUSED phase

        ## Preconditions

        - Execution must be in EXECUTION_PENDING or EXECUTION_IN_PROGRESS phase
        - Cannot pause already-terminal executions (COMPLETED, FAILED, CANCELLED, TERMINATED)

        ## State Transitions

        - status.phase: PENDING/IN_PROGRESS → PAUSED
        - status.completed_at: NOT set (execution is not finished)
        - Running activities: Gracefully cancelled, checkpoint saved
        - LangGraph state: Preserved via thread_id checkpoint

        ## Paused vs Cancelled

        | Aspect | pause | cancel |
        |--------|-------|--------|
        | Terminal state? | No | Yes |
        | Can resume? | Yes (via resume RPC) | No |
        | Checkpoint saved? | Yes | Best-effort |
        | Progress preserved? | Yes | No |
        | Use case | Temporary stop, maintenance | Permanent stop |

        ## Agent Activity Behavior

        When pause is signaled to a workflow running an agent:
        1. Workflow cancels the running activity gracefully
        2. Python activity catches CancelledError
        3. LangGraph saves final checkpoint automatically
        4. Activity returns with paused status
        5. On resume, activity loads from checkpoint and continues

        ## Idempotency

        Pausing an already-paused execution succeeds as a no-op.
        The call returns the current execution state without side effects.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission on the execution
        - FAILED_PRECONDITION: Execution is in a terminal phase
        - INVALID_ARGUMENT: ID is empty or malformed

        ## Example Request

        {
        "id": "wfx-abc123xyz456",
        "reason": "Pausing for scheduled maintenance window"
        }

        ## Example Response

        {
        "api_version": "agentic.stigmer.ai/v1",
        "kind": "WorkflowExecution",
        "metadata": { "id": "wfx-abc123xyz456" },
        "status": {
        "phase": 7,  // EXECUTION_PAUSED
        "started_at": "2026-02-07T10:00:00Z"
        // Note: completed_at is NOT set (execution can be resumed)
        }
        }

        @since Gap A3 (Pause/Resume Propagation)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def resume(self, request, context):
        """Resume a paused workflow execution.

        Continues execution from the checkpoint where it was paused. The workflow
        re-invokes activities with the same thread_id, which loads from checkpoint
        and continues from where it left off.

        ## Behavior

        1. Validates execution is in EXECUTION_PAUSED phase
        2. Sends "resume" signal to Temporal workflow
        3. Workflow receives signal and sets resumeSignalReceived flag
        4. Workflow re-invokes activity with same execution context
        5. Activity detects resume and loads from LangGraph checkpoint
        6. Execution transitions back to EXECUTION_IN_PROGRESS phase
        7. Returns updated WorkflowExecution with IN_PROGRESS phase

        ## Preconditions

        - Execution must be in EXECUTION_PAUSED phase
        - Cannot resume non-paused executions

        ## State Transitions

        - status.phase: PAUSED → IN_PROGRESS
        - Activities: Re-invoked, load from checkpoint
        - LangGraph state: Loaded from checkpoint via thread_id

        ## Resume Behavior

        When resume is signaled to a paused workflow:
        1. Java workflow unblocks from Workflow.await()
        2. Workflow re-invokes the activity with same parameters
        3. Python activity reads thread_id from heartbeat_details
        4. LangGraph loads checkpoint using thread_id
        5. Agent continues from exact position where it was paused

        ## Idempotency

        Resuming an already-running execution succeeds as a no-op.
        The call returns the current execution state without side effects.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission on the execution
        - FAILED_PRECONDITION: Execution is not in PAUSED phase
        - INVALID_ARGUMENT: ID is empty or malformed

        ## Example Request

        {
        "id": "wfx-abc123xyz456"
        }

        ## Example Response

        {
        "api_version": "agentic.stigmer.ai/v1",
        "kind": "WorkflowExecution",
        "metadata": { "id": "wfx-abc123xyz456" },
        "status": {
        "phase": 2,  // EXECUTION_IN_PROGRESS
        "started_at": "2026-02-07T10:00:00Z"
        }
        }

        @since Gap A3 (Pause/Resume Propagation)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowExecutionCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'updateStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.updateStatus,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.WorkflowExecutionUpdateStatusInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'submitApproval': grpc.unary_unary_rpc_method_handler(
                    servicer.submitApproval,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.SubmitWorkflowApprovalInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'sendSignal': grpc.unary_unary_rpc_method_handler(
                    servicer.sendSignal,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.SendSignalInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.cancel,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.CancelWorkflowExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'terminate': grpc.unary_unary_rpc_method_handler(
                    servicer.terminate,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.TerminateWorkflowExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'recover': grpc.unary_unary_rpc_method_handler(
                    servicer.recover,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.RecoverWorkflowExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'pause': grpc.unary_unary_rpc_method_handler(
                    servicer.pause,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.PauseWorkflowExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
            'resume': grpc.unary_unary_rpc_method_handler(
                    servicer.resume,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.ResumeWorkflowExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WorkflowExecutionCommandController(object):
    """WorkflowExecutionCommandController handles write operations (Create, Update, Delete) for WorkflowExecution resources.

    This service follows the Command-Query Separation (CQS) pattern:
    - CommandController: Write operations (create, update, delete)
    - QueryController: Read operations (get, list, search)

    Authorization:
    All RPCs use custom authorization logic implemented in middleware.
    Custom authorization is needed because:
    - create: Must verify user has "execute" permission on the referenced WorkflowInstance
    - update: Only the workflow runner (system) can update execution status, not users

    Service Options:
    - api_resource_kind: workflow_execution - Links this service to the WorkflowExecution resource
    """

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/create',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/update',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/updateStatus',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.WorkflowExecutionUpdateStatusInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def submitApproval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/submitApproval',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.SubmitWorkflowApprovalInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/delete',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def sendSignal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/sendSignal',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.SendSignalInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/cancel',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.CancelWorkflowExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def terminate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/terminate',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.TerminateWorkflowExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def recover(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/recover',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.RecoverWorkflowExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def pause(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/pause',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.PauseWorkflowExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def resume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionCommandController/resume',
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_io__pb2.ResumeWorkflowExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowexecution_dot_v1_dot_api__pb2.WorkflowExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as _api_pb2
from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as _enum_pb2
from ai.stigmer.agentic.agentexecution.v1 import usage_pb2 as _usage_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AgentExecutionId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class SessionId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class AgentExecutionList(_message.Message):
    __slots__ = ("total_pages", "entries")
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    total_pages: int
    entries: _containers.RepeatedCompositeFieldContainer[_api_pb2.AgentExecution]
    def __init__(self, total_pages: _Optional[int] = ..., entries: _Optional[_Iterable[_Union[_api_pb2.AgentExecution, _Mapping]]] = ...) -> None: ...

class ListAgentExecutionsRequest(_message.Message):
    __slots__ = ("page_size", "page_token", "phase", "tags")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PHASE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    phase: _enum_pb2.ExecutionPhase
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., phase: _Optional[_Union[_enum_pb2.ExecutionPhase, str]] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...

class ListAgentExecutionsBySessionRequest(_message.Message):
    __slots__ = ("session_id", "page_size", "page_token")
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    page_size: int
    page_token: str
    def __init__(self, session_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class AgentExecutionUpdateStatusInput(_message.Message):
    __slots__ = ("execution_id", "status")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    status: _api_pb2.AgentExecutionStatus
    def __init__(self, execution_id: _Optional[str] = ..., status: _Optional[_Union[_api_pb2.AgentExecutionStatus, _Mapping]] = ...) -> None: ...

class SubmitApprovalInput(_message.Message):
    __slots__ = ("agent_execution_id", "tool_call_id", "action", "comment")
    AGENT_EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    TOOL_CALL_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    agent_execution_id: str
    tool_call_id: str
    action: _enum_pb2.ApprovalAction
    comment: str
    def __init__(self, agent_execution_id: _Optional[str] = ..., tool_call_id: _Optional[str] = ..., action: _Optional[_Union[_enum_pb2.ApprovalAction, str]] = ..., comment: _Optional[str] = ...) -> None: ...

class ApprovalDecisionList(_message.Message):
    __slots__ = ("decisions",)
    DECISIONS_FIELD_NUMBER: _ClassVar[int]
    decisions: _containers.RepeatedCompositeFieldContainer[SubmitApprovalInput]
    def __init__(self, decisions: _Optional[_Iterable[_Union[SubmitApprovalInput, _Mapping]]] = ...) -> None: ...

class CancelAgentExecutionInput(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class TerminateAgentExecutionInput(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class RecoverAgentExecutionInput(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class PauseAgentExecutionInput(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class ResumeAgentExecutionInput(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class UploadAttachmentRequest(_message.Message):
    __slots__ = ("filename", "content", "content_type")
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    CONTENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    filename: str
    content: bytes
    content_type: str
    def __init__(self, filename: _Optional[str] = ..., content: _Optional[bytes] = ..., content_type: _Optional[str] = ...) -> None: ...

class UploadAttachmentResponse(_message.Message):
    __slots__ = ("storage_key",)
    STORAGE_KEY_FIELD_NUMBER: _ClassVar[int]
    storage_key: str
    def __init__(self, storage_key: _Optional[str] = ...) -> None: ...

class GetArtifactDownloadUrlRequest(_message.Message):
    __slots__ = ("execution_id", "storage_key")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    STORAGE_KEY_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    storage_key: str
    def __init__(self, execution_id: _Optional[str] = ..., storage_key: _Optional[str] = ...) -> None: ...

class GetArtifactDownloadUrlResponse(_message.Message):
    __slots__ = ("download_url", "expires_at")
    DOWNLOAD_URL_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    download_url: str
    expires_at: str
    def __init__(self, download_url: _Optional[str] = ..., expires_at: _Optional[str] = ...) -> None: ...

class GetArtifactContentRequest(_message.Message):
    __slots__ = ("execution_id", "storage_key", "max_bytes", "entry_path")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    STORAGE_KEY_FIELD_NUMBER: _ClassVar[int]
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    ENTRY_PATH_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    storage_key: str
    max_bytes: int
    entry_path: str
    def __init__(self, execution_id: _Optional[str] = ..., storage_key: _Optional[str] = ..., max_bytes: _Optional[int] = ..., entry_path: _Optional[str] = ...) -> None: ...

class GetArtifactContentResponse(_message.Message):
    __slots__ = ("content", "content_type", "total_size_bytes", "truncated")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    CONTENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    TRUNCATED_FIELD_NUMBER: _ClassVar[int]
    content: bytes
    content_type: str
    total_size_bytes: int
    truncated: bool
    def __init__(self, content: _Optional[bytes] = ..., content_type: _Optional[str] = ..., total_size_bytes: _Optional[int] = ..., truncated: bool = ...) -> None: ...

class GetSessionUsageReportInput(_message.Message):
    __slots__ = ("session_id",)
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    def __init__(self, session_id: _Optional[str] = ...) -> None: ...

class GetSessionUsageReportOutput(_message.Message):
    __slots__ = ("session_id", "execution_count", "total_usage", "executions", "model_breakdown", "total_summarization_cost_usd", "first_execution_at", "last_execution_at")
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_USAGE_FIELD_NUMBER: _ClassVar[int]
    EXECUTIONS_FIELD_NUMBER: _ClassVar[int]
    MODEL_BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SUMMARIZATION_COST_USD_FIELD_NUMBER: _ClassVar[int]
    FIRST_EXECUTION_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_EXECUTION_AT_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    execution_count: int
    total_usage: _usage_pb2.UsageMetrics
    executions: _containers.RepeatedCompositeFieldContainer[ExecutionUsageSummary]
    model_breakdown: _containers.RepeatedCompositeFieldContainer[_usage_pb2.ModelUsage]
    total_summarization_cost_usd: float
    first_execution_at: str
    last_execution_at: str
    def __init__(self, session_id: _Optional[str] = ..., execution_count: _Optional[int] = ..., total_usage: _Optional[_Union[_usage_pb2.UsageMetrics, _Mapping]] = ..., executions: _Optional[_Iterable[_Union[ExecutionUsageSummary, _Mapping]]] = ..., model_breakdown: _Optional[_Iterable[_Union[_usage_pb2.ModelUsage, _Mapping]]] = ..., total_summarization_cost_usd: _Optional[float] = ..., first_execution_at: _Optional[str] = ..., last_execution_at: _Optional[str] = ...) -> None: ...

class GetAgentUsageReportInput(_message.Message):
    __slots__ = ("agent_id", "from_date", "to_date", "page_size", "page_token")
    AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    FROM_DATE_FIELD_NUMBER: _ClassVar[int]
    TO_DATE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    agent_id: str
    from_date: str
    to_date: str
    page_size: int
    page_token: str
    def __init__(self, agent_id: _Optional[str] = ..., from_date: _Optional[str] = ..., to_date: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class GetAgentUsageReportOutput(_message.Message):
    __slots__ = ("agent_id", "agent_name", "total_usage", "model_breakdown", "sessions", "total_sessions", "total_executions", "total_cost_usd", "next_page_token")
    AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    AGENT_NAME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_USAGE_FIELD_NUMBER: _ClassVar[int]
    MODEL_BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SESSIONS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_EXECUTIONS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COST_USD_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    agent_id: str
    agent_name: str
    total_usage: _usage_pb2.UsageMetrics
    model_breakdown: _containers.RepeatedCompositeFieldContainer[_usage_pb2.ModelUsage]
    sessions: _containers.RepeatedCompositeFieldContainer[SessionUsageSummary]
    total_sessions: int
    total_executions: int
    total_cost_usd: float
    next_page_token: str
    def __init__(self, agent_id: _Optional[str] = ..., agent_name: _Optional[str] = ..., total_usage: _Optional[_Union[_usage_pb2.UsageMetrics, _Mapping]] = ..., model_breakdown: _Optional[_Iterable[_Union[_usage_pb2.ModelUsage, _Mapping]]] = ..., sessions: _Optional[_Iterable[_Union[SessionUsageSummary, _Mapping]]] = ..., total_sessions: _Optional[int] = ..., total_executions: _Optional[int] = ..., total_cost_usd: _Optional[float] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class GetOrgUsageReportInput(_message.Message):
    __slots__ = ("org_id", "from_date", "to_date")
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    FROM_DATE_FIELD_NUMBER: _ClassVar[int]
    TO_DATE_FIELD_NUMBER: _ClassVar[int]
    org_id: str
    from_date: str
    to_date: str
    def __init__(self, org_id: _Optional[str] = ..., from_date: _Optional[str] = ..., to_date: _Optional[str] = ...) -> None: ...

class GetOrgUsageReportOutput(_message.Message):
    __slots__ = ("org_id", "total_agents", "total_sessions", "total_executions", "total_cost_usd", "model_breakdown", "top_agents_by_cost", "daily_costs")
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_AGENTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SESSIONS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_EXECUTIONS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COST_USD_FIELD_NUMBER: _ClassVar[int]
    MODEL_BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
    TOP_AGENTS_BY_COST_FIELD_NUMBER: _ClassVar[int]
    DAILY_COSTS_FIELD_NUMBER: _ClassVar[int]
    org_id: str
    total_agents: int
    total_sessions: int
    total_executions: int
    total_cost_usd: float
    model_breakdown: _containers.RepeatedCompositeFieldContainer[_usage_pb2.ModelUsage]
    top_agents_by_cost: _containers.RepeatedCompositeFieldContainer[AgentUsageSummary]
    daily_costs: _containers.RepeatedCompositeFieldContainer[DailyCostEntry]
    def __init__(self, org_id: _Optional[str] = ..., total_agents: _Optional[int] = ..., total_sessions: _Optional[int] = ..., total_executions: _Optional[int] = ..., total_cost_usd: _Optional[float] = ..., model_breakdown: _Optional[_Iterable[_Union[_usage_pb2.ModelUsage, _Mapping]]] = ..., top_agents_by_cost: _Optional[_Iterable[_Union[AgentUsageSummary, _Mapping]]] = ..., daily_costs: _Optional[_Iterable[_Union[DailyCostEntry, _Mapping]]] = ...) -> None: ...

class ExecutionUsageSummary(_message.Message):
    __slots__ = ("execution_id", "started_at", "completed_at", "prompt_tokens", "completion_tokens", "cache_read_tokens", "estimated_cost_usd", "primary_model", "sub_agent_count", "phase")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
    PROMPT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CACHE_READ_TOKENS_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_COST_USD_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_MODEL_FIELD_NUMBER: _ClassVar[int]
    SUB_AGENT_COUNT_FIELD_NUMBER: _ClassVar[int]
    PHASE_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    started_at: str
    completed_at: str
    prompt_tokens: int
    completion_tokens: int
    cache_read_tokens: int
    estimated_cost_usd: float
    primary_model: str
    sub_agent_count: int
    phase: _enum_pb2.ExecutionPhase
    def __init__(self, execution_id: _Optional[str] = ..., started_at: _Optional[str] = ..., completed_at: _Optional[str] = ..., prompt_tokens: _Optional[int] = ..., completion_tokens: _Optional[int] = ..., cache_read_tokens: _Optional[int] = ..., estimated_cost_usd: _Optional[float] = ..., primary_model: _Optional[str] = ..., sub_agent_count: _Optional[int] = ..., phase: _Optional[_Union[_enum_pb2.ExecutionPhase, str]] = ...) -> None: ...

class SessionUsageSummary(_message.Message):
    __slots__ = ("session_id", "execution_count", "total_tokens", "estimated_cost_usd", "first_execution_at", "last_execution_at")
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TOKENS_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_COST_USD_FIELD_NUMBER: _ClassVar[int]
    FIRST_EXECUTION_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_EXECUTION_AT_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    execution_count: int
    total_tokens: int
    estimated_cost_usd: float
    first_execution_at: str
    last_execution_at: str
    def __init__(self, session_id: _Optional[str] = ..., execution_count: _Optional[int] = ..., total_tokens: _Optional[int] = ..., estimated_cost_usd: _Optional[float] = ..., first_execution_at: _Optional[str] = ..., last_execution_at: _Optional[str] = ...) -> None: ...

class AgentUsageSummary(_message.Message):
    __slots__ = ("agent_id", "agent_name", "execution_count", "total_tokens", "estimated_cost_usd")
    AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    AGENT_NAME_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TOKENS_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_COST_USD_FIELD_NUMBER: _ClassVar[int]
    agent_id: str
    agent_name: str
    execution_count: int
    total_tokens: int
    estimated_cost_usd: float
    def __init__(self, agent_id: _Optional[str] = ..., agent_name: _Optional[str] = ..., execution_count: _Optional[int] = ..., total_tokens: _Optional[int] = ..., estimated_cost_usd: _Optional[float] = ...) -> None: ...

class DailyCostEntry(_message.Message):
    __slots__ = ("date", "execution_count", "total_tokens", "estimated_cost_usd")
    DATE_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TOKENS_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_COST_USD_FIELD_NUMBER: _ClassVar[int]
    date: str
    execution_count: int
    total_tokens: int
    estimated_cost_usd: float
    def __init__(self, date: _Optional[str] = ..., execution_count: _Optional[int] = ..., total_tokens: _Optional[int] = ..., estimated_cost_usd: _Optional[float] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.iam.apikey.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2
from ai.stigmer.iam.apikey.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class ApiKeyQueryControllerStub(object):
    """api-key query controller
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/ai.stigmer.iam.apikey.v1.ApiKeyQueryController/get',
                request_serializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeyId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2.ApiKey.FromString,
                _registered_method=True)
        self.getByKeyHash = channel.unary_unary(
                '/ai.stigmer.iam.apikey.v1.ApiKeyQueryController/getByKeyHash',
                request_serializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeyHash.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2.ApiKey.FromString,
                _registered_method=True)
        self.findAll = channel.unary_unary(
                '/ai.stigmer.iam.apikey.v1.ApiKeyQueryController/findAll',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeys.FromString,
                _registered_method=True)


class ApiKeyQueryControllerServicer(object):
    """api-key query controller
    """

    def get(self, request, context):
        """lookup api-key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getByKeyHash(self, request, context):
        """lookup api-key by hashed key
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def findAll(self, request, context):
        """lookup all api-keys for the identity-account in the auth header.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ApiKeyQueryControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeyId.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2.ApiKey.SerializeToString,
            ),
            'getByKeyHash': grpc.unary_unary_rpc_method_handler(
                    servicer.getByKeyHash,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeyHash.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2.ApiKey.SerializeToString,
            ),
            'findAll': grpc.unary_unary_rpc_method_handler(
                    servicer.findAll,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeys.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.iam.apikey.v1.ApiKeyQueryController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.iam.apikey.v1.ApiKeyQueryController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ApiKeyQueryController(object):
    """api-key query controller
    """

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.apikey.v1.ApiKeyQueryController/get',
            ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeyId.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2.ApiKey.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getByKeyHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.apikey.v1.ApiKeyQueryController/getByKeyHash',
            ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeyHash.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2.ApiKey.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def findAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.apikey.v1.ApiKeyQueryController/findAll',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2.ApiKeys.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/skill/v1/synth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/skill/v1/synth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/stigmer/agentic/skill/v1/synth.proto\x12\x1b\x61i.stigmer.agentic.skill.v1\"\x9d\x01\n\nSkillSynth\x12=\n\x05local\x18\x01 \x01(\x0b\x32%.ai.stigmer.agentic.skill.v1.LocalDirH\x00R\x05local\x12\x34\n\x03git\x18\x02 \x01(\x0b\x32 .ai.stigmer.agentic.skill.v1.GitH\x00R\x03git\x12\x10\n\x03tag\x18\x03 \x01(\tR\x03tagB\x08\n\x06source\"\x1e\n\x08LocalDir\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\"A\n\x03Git\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12\x10\n\x03ref\x18\x02 \x01(\tR\x03ref\x12\x16\n\x06subdir\x18\x03 \x01(\tR\x06subdirB\xbe\x01\n\x1f\x63om.ai.stigmer.agentic.skill.v1B\nSynthProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1b\x41i.Stigmer.Agentic.Skill.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Skill\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Skill::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.skill.v1.synth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.skill.v1B\nSynthProtoP\001\242\002\004ASAS\252\002\033Ai.Stigmer.Agentic.Skill.V1\312\002\033Ai\\Stigmer\\Agentic\\Skill\\V1\342\002\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Skill::V1'
  _globals['_SKILLSYNTH']._serialized_start=73
  _globals['_SKILLSYNTH']._serialized_end=230
  _globals['_LOCALDIR']._serialized_start=232
  _globals['_LOCALDIR']._serialized_end=262
  _globals['_GIT']._serialized_start=264
  _globals['_GIT']._serialized_end=329
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ApiResourceGroup(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    api_resource_group_unspecified: _ClassVar[ApiResourceGroup]
    agentic: _ClassVar[ApiResourceGroup]
    iam: _ClassVar[ApiResourceGroup]
    tenancy: _ClassVar[ApiResourceGroup]
api_resource_group_unspecified: ApiResourceGroup
agentic: ApiResourceGroup
iam: ApiResourceGroup
tenancy: ApiResourceGroup
GROUP_META_FIELD_NUMBER: _ClassVar[int]
group_meta: _descriptor.FieldDescriptor

class ApiResourceGroupMeta(_message.Message):
    __slots__ = ("domain", "display_name")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    domain: str
    display_name: str
    def __init__(self, domain: _Optional[str] = ..., display_name: _Optional[str] = ...) -> None: ...



from ai.stigmer.agentic.agent.v1 import spec_pb2 as _spec_pb2
from ai.stigmer.agentic.session.v1 import workspace_pb2 as _workspace_pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SessionSpec(_message.Message):
    __slots__ = ("agent_instance_id", "subject", "thread_id", "sandbox_id", "metadata", "workspace_entries", "mcp_server_usages", "skill_refs")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    AGENT_INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    THREAD_ID_FIELD_NUMBER: _ClassVar[int]
    SANDBOX_ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    MCP_SERVER_USAGES_FIELD_NUMBER: _ClassVar[int]
    SKILL_REFS_FIELD_NUMBER: _ClassVar[int]
    agent_instance_id: str
    subject: str
    thread_id: str
    sandbox_id: str
    metadata: _containers.ScalarMap[str, str]
    workspace_entries: _containers.RepeatedCompositeFieldContainer[_workspace_pb2.WorkspaceEntry]
    mcp_server_usages: _containers.RepeatedCompositeFieldContainer[_spec_pb2.McpServerUsage]
    skill_refs: _containers.RepeatedCompositeFieldContainer[_io_pb2.ApiResourceReference]
    def __init__(self, agent_instance_id: _Optional[str] = ..., subject: _Optional[str] = ..., thread_id: _Optional[str] = ..., sandbox_id: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., workspace_entries: _Optional[_Iterable[_Union[_workspace_pb2.WorkspaceEntry, _Mapping]]] = ..., mcp_server_usages: _Optional[_Iterable[_Union[_spec_pb2.McpServerUsage, _Mapping]]] = ..., skill_refs: _Optional[_Iterable[_Union[_io_pb2.ApiResourceReference, _Mapping]]] = ...) -> None: ...



from ai.stigmer.agentic.session.v1 import api_pb2 as _api_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SessionId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class AgentId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class SessionList(_message.Message):
    __slots__ = ("total_pages", "entries")
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    total_pages: int
    entries: _containers.RepeatedCompositeFieldContainer[_api_pb2.Session]
    def __init__(self, total_pages: _Optional[int] = ..., entries: _Optional[_Iterable[_Union[_api_pb2.Session, _Mapping]]] = ...) -> None: ...

class ListSessionsRequest(_message.Message):
    __slots__ = ("page_size", "page_token", "tags")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...

class ListSessionsByAgentRequest(_message.Message):
    __slots__ = ("agent_id", "page_size", "page_token")
    AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    agent_id: str
    page_size: int
    page_token: str
    def __init__(self, agent_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_group_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__group__pb2
from ai.stigmer.commons.apiresource.apiresourcekind import authorization_config_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_authorization__config__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFai/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x12.ai.stigmer.commons.apiresource.apiresourcekind\x1aGai/stigmer/commons/apiresource/apiresourcekind/api_resource_group.proto\x1aIai/stigmer/commons/apiresource/apiresourcekind/authorization_config.proto\x1a google/protobuf/descriptor.proto\"\xad\x04\n\x13\x41piResourceKindMeta\x12V\n\x05group\x18\x01 \x01(\x0e\x32@.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceGroupR\x05group\x12\\\n\x07version\x18\x02 \x01(\x0e\x32\x42.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceVersionR\x07version\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12!\n\x0c\x64isplay_name\x18\x04 \x01(\tR\x0b\x64isplayName\x12\x1b\n\tid_prefix\x18\x05 \x01(\tR\x08idPrefix\x12!\n\x0cis_versioned\x18\x06 \x01(\x08R\x0bisVersioned\x12,\n\x12not_search_indexed\x18\x07 \x01(\x08R\x10notSearchIndexed\x12P\n\x04tier\x18\x08 \x01(\x0e\x32<.ai.stigmer.commons.apiresource.apiresourcekind.ResourceTierR\x04tier\x12i\n\rauthorization\x18\t \x01(\x0b\x32\x43.ai.stigmer.commons.apiresource.apiresourcekind.AuthorizationConfigR\rauthorization*B\n\x12\x41piResourceVersion\x12$\n api_resource_version_unspecified\x10\x00\x12\x06\n\x02v1\x10\x01*N\n\x0cResourceTier\x12\x1d\n\x19resource_tier_unspecified\x10\x00\x12\x0f\n\x0bopen_source\x10\x01\x12\x0e\n\ncloud_only\x10\x02*A\n\x0fPlatformIdValue\x12!\n\x1dplatform_id_value_unspecified\x10\x00\x12\x0b\n\x07stigmer\x10\x01*\xb8\x0b\n\x0f\x41piResourceKind\x12\x1d\n\x19\x61pi_resource_kind_unknown\x10\x00\x12[\n\x14\x61pi_resource_version\x10\x01\x1a\x41\xaa\xff+=\x08\x01\x10\x01\x1a\x12\x41piResourceVersion\"\x14\x41PI Resource Version*\x03ver8\x01@\x02J\x04\x08\x05\x10\x04\x12?\n\niam_policy\x10\n\x1a/\xaa\xff++\x08\x02\x10\x01\x1a\tIamPolicy\"\nIAM Policy*\x04iamp8\x01@\x02J\x04\x08\x02\x10\x01\x12N\n\x10identity_account\x10\x0b\x1a\x38\xaa\xff+4\x08\x02\x10\x01\x1a\x0fIdentityAccount\"\x10Identity Account*\x03ida@\x02J\x04\x08\x04\x10\x03\x12\x35\n\x07\x61pi_key\x10\x0c\x1a(\xaa\xff+$\x08\x02\x10\x01\x1a\x06\x41piKey\"\x07\x41PI Key*\x03key8\x01@\x02J\x04\x08\x04\x10\x01\x12S\n\x11identity_provider\x10\x15\x1a<\xaa\xff+8\x08\x02\x10\x01\x1a\x10IdentityProvider\"\x11Identity Provider*\x03idp8\x01@\x02J\x04\x08\x02\x10\x01\x12\x43\n\x0corganization\x10\x1e\x1a\x31\xaa\xff+-\x08\x03\x10\x01\x1a\x0cOrganization\"\x0cOrganization*\x03org@\x01J\x04\x08\x04\x10\x01\x12\x39\n\x08platform\x10\x1f\x1a+\xaa\xff+\'\x08\x03\x10\x01\x1a\x08Platform\"\x08Platform*\x03plt8\x01@\x02J\x04\x08\x05\x10\x04\x12\x32\n\x05\x61gent\x10(\x1a\'\xaa\xff+#\x08\x01\x10\x01\x1a\x05\x41gent\"\x05\x41gent*\x03\x61gt@\x01J\x08\x08\x02\x10\x01*\x02\x08\x01\x12k\n\x0f\x61gent_execution\x10)\x1aV\xaa\xff+R\x08\x01\x10\x01\x1a\x0e\x41gentExecution\"\x0f\x41gent Execution*\x03\x61\x65x@\x01J$\x08\x03\x10\x02\x1a\x1e\n\x07session\x12\x07session\x1a\nsession_id\x12\x34\n\x07session\x10*\x1a\'\xaa\xff+#\x08\x01\x10\x01\x1a\x07Session\"\x07Session*\x03ses@\x01J\x04\x08\x02\x10\x01\x12\x34\n\x05skill\x10+\x1a)\xaa\xff+%\x08\x01\x10\x01\x1a\x05Skill\"\x05Skill*\x03skl0\x01@\x01J\x08\x08\x02\x10\x01*\x02\x08\x01\x12@\n\nmcp_server\x10,\x1a\x30\xaa\xff+,\x08\x01\x10\x01\x1a\tMcpServer\"\nMCP Server*\x03mcp@\x01J\x08\x08\x02\x10\x01*\x02\x08\x01\x12\x66\n\x0e\x61gent_instance\x10-\x1aR\xaa\xff+N\x08\x01\x10\x01\x1a\rAgentInstance\"\x0e\x41gent Instance*\x03\x61in@\x01J\"\x08\x02\x10\x01\"\x18\n\x05\x61gent\x12\x05\x61gent\x1a\x08\x61gent_id*\x02\x08\x01\x12;\n\x08workflow\x10\x32\x1a-\xaa\xff+)\x08\x01\x10\x01\x1a\x08Workflow\"\x08Workflow*\x03wfl@\x01J\x08\x08\x02\x10\x01*\x02\x08\x01\x12t\n\x11workflow_instance\x10\x33\x1a]\xaa\xff+Y\x08\x01\x10\x01\x1a\x10WorkflowInstance\"\x11Workflow Instance*\x03win@\x01J\'\x08\x02\x10\x01\"!\n\x08workflow\x12\x08workflow\x1a\x0bworkflow_id\x12T\n\x12workflow_execution\x10\x34\x1a<\xaa\xff+8\x08\x01\x10\x01\x1a\x11WorkflowExecution\"\x12Workflow Execution*\x03wex@\x01J\x04\x08\x02\x10\x01\x12\x42\n\x0b\x65nvironment\x10\x35\x1a\x31\xaa\xff+-\x08\x01\x10\x01\x1a\x0b\x45nvironment\"\x0b\x45nvironment*\x03\x65nv@\x01J\x06\x08\x02\x10\x01\x30\x01\x12R\n\x11\x65xecution_context\x10\x36\x1a;\xaa\xff+7\x08\x01\x10\x01\x1a\x10\x45xecutionContext\"\x11\x45xecution Context*\x04\x65xec@\x01J\x04\x08\x05\x10\x04\x12\x34\n\x07project\x10<\x1a\'\xaa\xff+#\x08\x03\x10\x01\x1a\x07Project\"\x07Project*\x03prj@\x01J\x04\x08\x02\x10\x01:\x85\x01\n\tkind_meta\x12!.google.protobuf.EnumValueOptions\x18\xf5\xbf\x05 \x01(\x0b\x32\x43.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindMetaR\x08kindMetaB\xa8\x02\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\x14\x41piResourceKindProtoP\x01\xa2\x02\x05\x41SCAA\xaa\x02.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\xca\x02.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\xe2\x02:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\xea\x02\x32\x41i::Stigmer::Commons::Apiresource::Apiresourcekindb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.apiresourcekind.api_resource_kind_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\024ApiResourceKindProtoP\001\242\002\005ASCAA\252\002.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\312\002.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\342\002:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\352\0022Ai::Stigmer::Commons::Apiresource::Apiresourcekind'
  _globals['_APIRESOURCEKIND'].values_by_name["api_resource_version"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["api_resource_version"]._serialized_options = b'\252\377+=\010\001\020\001\032\022ApiResourceVersion\"\024API Resource Version*\003ver8\001@\002J\004\010\005\020\004'
  _globals['_APIRESOURCEKIND'].values_by_name["iam_policy"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["iam_policy"]._serialized_options = b'\252\377++\010\002\020\001\032\tIamPolicy\"\nIAM Policy*\004iamp8\001@\002J\004\010\002\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["identity_account"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["identity_account"]._serialized_options = b'\252\377+4\010\002\020\001\032\017IdentityAccount\"\020Identity Account*\003ida@\002J\004\010\004\020\003'
  _globals['_APIRESOURCEKIND'].values_by_name["api_key"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["api_key"]._serialized_options = b'\252\377+$\010\002\020\001\032\006ApiKey\"\007API Key*\003key8\001@\002J\004\010\004\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["identity_provider"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["identity_provider"]._serialized_options = b'\252\377+8\010\002\020\001\032\020IdentityProvider\"\021Identity Provider*\003idp8\001@\002J\004\010\002\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["organization"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["organization"]._serialized_options = b'\252\377+-\010\003\020\001\032\014Organization\"\014Organization*\003org@\001J\004\010\004\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["platform"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["platform"]._serialized_options = b'\252\377+\'\010\003\020\001\032\010Platform\"\010Platform*\003plt8\001@\002J\004\010\005\020\004'
  _globals['_APIRESOURCEKIND'].values_by_name["agent"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["agent"]._serialized_options = b'\252\377+#\010\001\020\001\032\005Agent\"\005Agent*\003agt@\001J\010\010\002\020\001*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["agent_execution"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["agent_execution"]._serialized_options = b'\252\377+R\010\001\020\001\032\016AgentExecution\"\017Agent Execution*\003aex@\001J$\010\003\020\002\032\036\n\007session\022\007session\032\nsession_id'
  _globals['_APIRESOURCEKIND'].values_by_name["session"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["session"]._serialized_options = b'\252\377+#\010\001\020\001\032\007Session\"\007Session*\003ses@\001J\004\010\002\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["skill"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["skill"]._serialized_options = b'\252\377+%\010\001\020\001\032\005Skill\"\005Skill*\003skl0\001@\001J\010\010\002\020\001*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["mcp_server"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["mcp_server"]._serialized_options = b'\252\377+,\010\001\020\001\032\tMcpServer\"\nMCP Server*\003mcp@\001J\010\010\002\020\001*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["agent_instance"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["agent_instance"]._serialized_options = b'\252\377+N\010\001\020\001\032\rAgentInstance\"\016Agent Instance*\003ain@\001J\"\010\002\020\001\"\030\n\005agent\022\005agent\032\010agent_id*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["workflow"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["workflow"]._serialized_options = b'\252\377+)\010\001\020\001\032\010Workflow\"\010Workflow*\003wfl@\001J\010\010\002\020\001*\002\010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["workflow_instance"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["workflow_instance"]._serialized_options = b'\252\377+Y\010\001\020\001\032\020WorkflowInstance\"\021Workflow Instance*\003win@\001J\'\010\002\020\001\"!\n\010workflow\022\010workflow\032\013workflow_id'
  _globals['_APIRESOURCEKIND'].values_by_name["workflow_execution"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["workflow_execution"]._serialized_options = b'\252\377+8\010\001\020\001\032\021WorkflowExecution\"\022Workflow Execution*\003wex@\001J\004\010\002\020\001'
  _globals['_APIRESOURCEKIND'].values_by_name["environment"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["environment"]._serialized_options = b'\252\377+-\010\001\020\001\032\013Environment\"\013Environment*\003env@\001J\006\010\002\020\0010\001'
  _globals['_APIRESOURCEKIND'].values_by_name["execution_context"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["execution_context"]._serialized_options = b'\252\377+7\010\001\020\001\032\020ExecutionContext\"\021Execution Context*\004exec@\001J\004\010\005\020\004'
  _globals['_APIRESOURCEKIND'].values_by_name["project"]._loaded_options = None
  _globals['_APIRESOURCEKIND'].values_by_name["project"]._serialized_options = b'\252\377+#\010\003\020\001\032\007Project\"\007Project*\003prj@\001J\004\010\002\020\001'
  _globals['_APIRESOURCEVERSION']._serialized_start=864
  _globals['_APIRESOURCEVERSION']._serialized_end=930
  _globals['_RESOURCETIER']._serialized_start=932
  _globals['_RESOURCETIER']._serialized_end=1010
  _globals['_PLATFORMIDVALUE']._serialized_start=1012
  _globals['_PLATFORMIDVALUE']._serialized_end=1077
  _globals['_APIRESOURCEKIND']._serialized_start=1080
  _globals['_APIRESOURCEKIND']._serialized_end=2544
  _globals['_APIRESOURCEKINDMETA']._serialized_start=305
  _globals['_APIRESOURCEKINDMETA']._serialized_end=862
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowexecution/v1/enum.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowexecution/v1/enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/stigmer/agentic/workflowexecution/v1/enum.proto\x12\'ai.stigmer.agentic.workflowexecution.v1*\xdb\x01\n\x0e\x45xecutionPhase\x12\x1f\n\x1b\x45XECUTION_PHASE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x45XECUTION_PENDING\x10\x01\x12\x19\n\x15\x45XECUTION_IN_PROGRESS\x10\x02\x12\x17\n\x13\x45XECUTION_COMPLETED\x10\x03\x12\x14\n\x10\x45XECUTION_FAILED\x10\x04\x12\x17\n\x13\x45XECUTION_CANCELLED\x10\x05\x12\x18\n\x14\x45XECUTION_TERMINATED\x10\x06\x12\x14\n\x10\x45XECUTION_PAUSED\x10\x07*\x84\x02\n\x10WorkflowTaskType\x12\"\n\x1eWORKFLOW_TASK_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1eWORKFLOW_TASK_AGENT_INVOCATION\x10\x01\x12\x1a\n\x16WORKFLOW_TASK_APPROVAL\x10\x02\x12\x1a\n\x16WORKFLOW_TASK_API_CALL\x10\x03\x12\x1d\n\x19WORKFLOW_TASK_CONDITIONAL\x10\x04\x12\x1a\n\x16WORKFLOW_TASK_PARALLEL\x10\x05\x12\x1b\n\x17WORKFLOW_TASK_TRANSFORM\x10\x06\x12\x18\n\x14WORKFLOW_TASK_CUSTOM\x10\x07*\xea\x01\n\x12WorkflowTaskStatus\x12$\n WORKFLOW_TASK_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15WORKFLOW_TASK_PENDING\x10\x01\x12\x1d\n\x19WORKFLOW_TASK_IN_PROGRESS\x10\x02\x12\x1b\n\x17WORKFLOW_TASK_COMPLETED\x10\x03\x12\x18\n\x14WORKFLOW_TASK_FAILED\x10\x04\x12\x19\n\x15WORKFLOW_TASK_SKIPPED\x10\x05\x12\"\n\x1eWORKFLOW_TASK_WAITING_APPROVAL\x10\x06\x42\xf9\x01\n+com.ai.stigmer.agentic.workflowexecution.v1B\tEnumProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\'Ai.Stigmer.Agentic.Workflowexecution.V1\xca\x02\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\xe2\x02\x33\x41i\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\xea\x02+Ai::Stigmer::Agentic::Workflowexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowexecution.v1.enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ai.stigmer.agentic.workflowexecution.v1B\tEnumProtoP\001\242\002\004ASAW\252\002\'Ai.Stigmer.Agentic.Workflowexecution.V1\312\002\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\342\0023Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\352\002+Ai::Stigmer::Agentic::Workflowexecution::V1'
  _globals['_EXECUTIONPHASE']._serialized_start=96
  _globals['_EXECUTIONPHASE']._serialized_end=315
  _globals['_WORKFLOWTASKTYPE']._serialized_start=318
  _globals['_WORKFLOWTASKTYPE']._serialized_end=578
  _globals['_WORKFLOWTASKSTATUS']._serialized_start=581
  _globals['_WORKFLOWTASKSTATUS']._serialized_end=815
# @@protoc_insertion_point(module_scope)



from ai.stigmer.agentic.environment.v1 import spec_pb2 as _spec_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class McpServerSpec(_message.Message):
    __slots__ = ("description", "icon_url", "tags", "stdio", "http", "default_enabled_tools", "env_spec", "default_tool_approvals")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ICON_URL_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    STDIO_FIELD_NUMBER: _ClassVar[int]
    HTTP_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_ENABLED_TOOLS_FIELD_NUMBER: _ClassVar[int]
    ENV_SPEC_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_TOOL_APPROVALS_FIELD_NUMBER: _ClassVar[int]
    description: str
    icon_url: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    stdio: StdioServerConfig
    http: HttpServerConfig
    default_enabled_tools: _containers.RepeatedScalarFieldContainer[str]
    env_spec: _spec_pb2.EnvironmentSpec
    default_tool_approvals: _containers.RepeatedCompositeFieldContainer[ToolApprovalPolicy]
    def __init__(self, description: _Optional[str] = ..., icon_url: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., stdio: _Optional[_Union[StdioServerConfig, _Mapping]] = ..., http: _Optional[_Union[HttpServerConfig, _Mapping]] = ..., default_enabled_tools: _Optional[_Iterable[str]] = ..., env_spec: _Optional[_Union[_spec_pb2.EnvironmentSpec, _Mapping]] = ..., default_tool_approvals: _Optional[_Iterable[_Union[ToolApprovalPolicy, _Mapping]]] = ...) -> None: ...

class StdioServerConfig(_message.Message):
    __slots__ = ("command", "args", "working_dir")
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    ARGS_FIELD_NUMBER: _ClassVar[int]
    WORKING_DIR_FIELD_NUMBER: _ClassVar[int]
    command: str
    args: _containers.RepeatedScalarFieldContainer[str]
    working_dir: str
    def __init__(self, command: _Optional[str] = ..., args: _Optional[_Iterable[str]] = ..., working_dir: _Optional[str] = ...) -> None: ...

class HttpServerConfig(_message.Message):
    __slots__ = ("url", "headers", "query_params", "timeout_seconds")
    class HeadersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class QueryParamsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    URL_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    QUERY_PARAMS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_SECONDS_FIELD_NUMBER: _ClassVar[int]
    url: str
    headers: _containers.ScalarMap[str, str]
    query_params: _containers.ScalarMap[str, str]
    timeout_seconds: int
    def __init__(self, url: _Optional[str] = ..., headers: _Optional[_Mapping[str, str]] = ..., query_params: _Optional[_Mapping[str, str]] = ..., timeout_seconds: _Optional[int] = ...) -> None: ...

class ToolApprovalPolicy(_message.Message):
    __slots__ = ("tool_name", "message")
    TOOL_NAME_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    tool_name: str
    message: str
    def __init__(self, tool_name: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...



from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as _enum_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecutionArtifact(_message.Message):
    __slots__ = ("name", "sandbox_path", "kind", "size_bytes", "storage_key", "download_url", "created_at", "expires_at", "entries")
    NAME_FIELD_NUMBER: _ClassVar[int]
    SANDBOX_PATH_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    STORAGE_KEY_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_URL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    name: str
    sandbox_path: str
    kind: _enum_pb2.ExecutionArtifactKind
    size_bytes: int
    storage_key: str
    download_url: str
    created_at: str
    expires_at: str
    entries: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., sandbox_path: _Optional[str] = ..., kind: _Optional[_Union[_enum_pb2.ExecutionArtifactKind, str]] = ..., size_bytes: _Optional[int] = ..., storage_key: _Optional[str] = ..., download_url: _Optional[str] = ..., created_at: _Optional[str] = ..., expires_at: _Optional[str] = ..., entries: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/stigmer/agentic/agentexecution/v1/command.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a.ai/stigmer/agentic/agentexecution/v1/api.proto\x1a-ai/stigmer/agentic/agentexecution/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xe4\x0f\n\x1f\x41gentExecutionCommandController\x12z\n\x06\x63reate\x12\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"\x04\xd0\xb8\x18\x01\x12\xb3\x01\n\x06update\x12\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"=\xc2\xb8\x18\x39\x08\x04\x10)\"\x0bmetadata.id*&unauthorized to update agent execution\x12\xcd\x01\n\x0cupdateStatus\x12\x45.ai.stigmer.agentic.agentexecution.v1.AgentExecutionUpdateStatusInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"@\xc2\xb8\x18<\x08\x1f\x10\x1f*-unauthorized to update agent execution status2\x07stigmer\x12\xa6\x01\n\x06\x64\x65lete\x12-.ai.stigmer.commons.apiresource.ApiResourceId\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"7\xc2\xb8\x18\x33\x08\x04\x10)\"\x05value*&unauthorized to delete agent execution\x12\xd4\x01\n\x0esubmitApproval\x12\x39.ai.stigmer.agentic.agentexecution.v1.SubmitApprovalInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"Q\xc2\xb8\x18M\x08\x04\x10)\"\x12\x61gent_execution_id*3unauthorized to submit approval for agent execution\x12\xb5\x01\n\x06\x63\x61ncel\x12?.ai.stigmer.agentic.agentexecution.v1.CancelAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"4\xc2\xb8\x18\x30\x08\x04\x10)\"\x02id*&unauthorized to cancel agent execution\x12\xbe\x01\n\tterminate\x12\x42.ai.stigmer.agentic.agentexecution.v1.TerminateAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"7\xc2\xb8\x18\x33\x08\x04\x10)\"\x02id*)unauthorized to terminate agent execution\x12\xb8\x01\n\x07recover\x12@.ai.stigmer.agentic.agentexecution.v1.RecoverAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"5\xc2\xb8\x18\x31\x08\x04\x10)\"\x02id*\'unauthorized to recover agent execution\x12\xb2\x01\n\x05pause\x12>.ai.stigmer.agentic.agentexecution.v1.PauseAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"3\xc2\xb8\x18/\x08\x04\x10)\"\x02id*%unauthorized to pause agent execution\x12\xb5\x01\n\x06resume\x12?.ai.stigmer.agentic.agentexecution.v1.ResumeAgentExecutionInput\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"4\xc2\xb8\x18\x30\x08\x04\x10)\"\x02id*&unauthorized to resume agent execution\x12\x97\x01\n\x10uploadAttachment\x12=.ai.stigmer.agentic.agentexecution.v1.UploadAttachmentRequest\x1a>.ai.stigmer.agentic.agentexecution.v1.UploadAttachmentResponse\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+)B\xed\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\014CommandProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER']._serialized_options = b'\240\377+)'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0309\010\004\020)\"\013metadata.id*&unauthorized to update agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['updateStatus']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['updateStatus']._serialized_options = b'\302\270\030<\010\037\020\037*-unauthorized to update agent execution status2\007stigmer'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0303\010\004\020)\"\005value*&unauthorized to delete agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['submitApproval']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['submitApproval']._serialized_options = b'\302\270\030M\010\004\020)\"\022agent_execution_id*3unauthorized to submit approval for agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['cancel']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['cancel']._serialized_options = b'\302\270\0300\010\004\020)\"\002id*&unauthorized to cancel agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['terminate']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['terminate']._serialized_options = b'\302\270\0303\010\004\020)\"\002id*)unauthorized to terminate agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['recover']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['recover']._serialized_options = b'\302\270\0301\010\004\020)\"\002id*\'unauthorized to recover agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['pause']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['pause']._serialized_options = b'\302\270\030/\010\004\020)\"\002id*%unauthorized to pause agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['resume']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['resume']._serialized_options = b'\302\270\0300\010\004\020)\"\002id*&unauthorized to resume agent execution'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['uploadAttachment']._loaded_options = None
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER'].methods_by_name['uploadAttachment']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER']._serialized_start=354
  _globals['_AGENTEXECUTIONCOMMANDCONTROLLER']._serialized_end=2374
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/tasks/agent_call.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/tasks/agent_call.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_spec__pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ai/stigmer/agentic/workflow/v1/tasks/agent_call.proto\x12$ai.stigmer.agentic.workflow.v1.tasks\x1a/ai/stigmer/agentic/agentexecution/v1/spec.proto\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\"\xe7\x02\n\x13\x41gentCallTaskConfig\x12\"\n\x05\x61gent\x18\x01 \x01(\tB\x0c\xbaH\tr\x04\x10\x01\x18\x7f\xc8\x01\x01R\x05\x61gent\x12\x10\n\x03org\x18\x02 \x01(\tR\x03org\x12(\n\x07message\x18\x03 \x01(\tB\x0e\xbaH\x07r\x02\x10\x01\xc8\x01\x01\xd8\x85,\x01R\x07message\x12T\n\x03\x65nv\x18\x04 \x03(\x0b\x32\x42.ai.stigmer.agentic.workflow.v1.tasks.AgentCallTaskConfig.EnvEntryR\x03\x65nv\x12R\n\x06\x63onfig\x18\x05 \x01(\x0b\x32:.ai.stigmer.agentic.workflow.v1.tasks.AgentExecutionConfigR\x06\x63onfig\x1a\x36\n\x08\x45nvEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01:\x0e\xea\x8b,\nagent_call\"\xf3\x01\n\x14\x41gentExecutionConfig\x12\x14\n\x05model\x18\x01 \x01(\tR\x05model\x12$\n\x07timeout\x18\x02 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\x90\x1c(\x01R\x07timeout\x12\x31\n\x0btemperature\x18\x03 \x01(\x02\x42\x0f\xbaH\x0c\n\n\x1d\x00\x00\x80?-\x00\x00\x00\x00R\x0btemperature\x12l\n\x12\x63ontext_management\x18\x04 \x01(\x0b\x32=.ai.stigmer.agentic.agentexecution.v1.ContextManagementConfigR\x11\x63ontextManagementB\xf2\x01\n(com.ai.stigmer.agentic.workflow.v1.tasksB\x0e\x41gentCallProtoP\x01\xa2\x02\x06\x41SAWVT\xaa\x02$Ai.Stigmer.Agentic.Workflow.V1.Tasks\xca\x02$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\xea\x02)Ai::Stigmer::Agentic::Workflow::V1::Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.tasks.agent_call_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.workflow.v1.tasksB\016AgentCallProtoP\001\242\002\006ASAWVT\252\002$Ai.Stigmer.Agentic.Workflow.V1.Tasks\312\002$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\342\0020Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\352\002)Ai::Stigmer::Agentic::Workflow::V1::Tasks'
  _globals['_AGENTCALLTASKCONFIG_ENVENTRY']._loaded_options = None
  _globals['_AGENTCALLTASKCONFIG_ENVENTRY']._serialized_options = b'8\001'
  _globals['_AGENTCALLTASKCONFIG'].fields_by_name['agent']._loaded_options = None
  _globals['_AGENTCALLTASKCONFIG'].fields_by_name['agent']._serialized_options = b'\272H\tr\004\020\001\030\177\310\001\001'
  _globals['_AGENTCALLTASKCONFIG'].fields_by_name['message']._loaded_options = None
  _globals['_AGENTCALLTASKCONFIG'].fields_by_name['message']._serialized_options = b'\272H\007r\002\020\001\310\001\001\330\205,\001'
  _globals['_AGENTCALLTASKCONFIG']._loaded_options = None
  _globals['_AGENTCALLTASKCONFIG']._serialized_options = b'\352\213,\nagent_call'
  _globals['_AGENTEXECUTIONCONFIG'].fields_by_name['timeout']._loaded_options = None
  _globals['_AGENTEXECUTIONCONFIG'].fields_by_name['timeout']._serialized_options = b'\272H\007\032\005\030\220\034(\001'
  _globals['_AGENTEXECUTIONCONFIG'].fields_by_name['temperature']._loaded_options = None
  _globals['_AGENTEXECUTIONCONFIG'].fields_by_name['temperature']._serialized_options = b'\272H\014\n\n\035\000\000\200?-\000\000\000\000'
  _globals['_AGENTCALLTASKCONFIG']._serialized_start=226
  _globals['_AGENTCALLTASKCONFIG']._serialized_end=585
  _globals['_AGENTCALLTASKCONFIG_ENVENTRY']._serialized_start=515
  _globals['_AGENTCALLTASKCONFIG_ENVENTRY']._serialized_end=569
  _globals['_AGENTEXECUTIONCONFIG']._serialized_start=588
  _globals['_AGENTEXECUTIONCONFIG']._serialized_end=831
# @@protoc_insertion_point(module_scope)
